import MySQLdb as sql

# per far funzionare su gitlab usare questi valori
# Host: mysql
# User: runner
# Password: Databasepss20/21
# Database: assignment1
#db = sql.connect(host="mysql", user="runner", passwd="Databasepss20/21", db="assignment1")# noqa
db = sql.connect(host="mysql", user="root", passwd="Databasepss20/21", db="assignment1")# noqa
cursor = db.cursor()
create_table = """DROP TABLE IF EXISTS `metadata`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
 SET character_set_client = utf8mb4 ;
CREATE TABLE `metadata` (
  `id` int(4) NOT NULL,
  `nome` varchar(20) NOT NULL,
  `estensione` varchar(4) NOT NULL,
  `percorso` varchar(45) NOT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;"""
populate_table = """LOCK TABLES `metadata` WRITE;
/*!40000 ALTER TABLE `metadata` DISABLE KEYS */;
INSERT INTO `metadata` VALUES (1,'neve','jpg','immagini/neve.jpg'),(2,'ghepardo','jpg','immagini/ghepardo.jpg'),(3,'flower','jpg','immagini/flower.jpg'),(4,'cioccolatino','jpg','immagini/cioccolatino.jpg'),(5,'arancia','jpg','immagini/arancia.jpg');
/*!40000 ALTER TABLE `metadata` ENABLE KEYS */;
UNLOCK TABLES;"""
cursor.execute(create_table)
cursor.nextset()
cursor.execute(populate_table)



import MySQLdb as sql
import random
import numpy
import pytest
import matplotlib.pyplot as plt
from main import get_im_from_db

def test_integration():
    image = []
    image2 = []
    try:
        # per far funzionare su gitlab usare questi valori
        # Host: mysql
        # User: runner
        # Password: Databasepss20/21
        # Database: assignment1
        # normalmente la porta è 3306
        #db = sql.connect(host="mysql", user="runner", passwd="Databasepss20/21", db="Assignment1")#noqa
        db=sql.connect(host="mysql", user="runner", passwd="Databasepss20/21", db="assignment1")# noqa
        print("connessione eseguita")
    except:
        pytest.fail("errore durante la connessione al db")
    try:
        cursor = db.cursor()
        indice = random.randint(1, 5)
        image = get_im_from_db(indice, "mysql")
        query = "SELECT percorso FROM metadata WHERE id =" + str(indice)
        cursor.execute(query)
        print("query eseguita")
        # results = cursor.fetchall()
        results = cursor.fetchone()
        image2 = plt.imread(str(results[0]))
        assert len(image) == len(image2)
        numpy.testing.assert_array_equal(image, image2)
    except:
        pytest.fail("errore durante la query di richiesta del percorso di un immagine")



import os
from setuptools import setup

def read(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()

setup(
    name = "pss_marta_danilo",
    version = "0.0.18",
    author = "Danilo Marta",
    description = ("..."),
    license = "BSD",
    packages = ['pss-marta-danilo'],
    keywords = "example documentation tutorial",
    url = "http://packages.python.org/pss_marta_danilo",
    long_description=read('README.md'),
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Topic :: Utilities",
        "License :: OSI Approved :: BSD License",
    ],
)
